@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bisoimager.cpp,v 1.19.2.6 2004/06/17 16:03:05 trueg Exp $
+ * $Id: k3bisoimager.cpp,v 1.19.2.9 2004/12/11 16:44:09 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -251,13 +251,12 @@ void K3bIsoImager::calculateSize()
   m_doc->prepareFilenames();
 
   if( !prepareMkisofsFiles() || 
-      !addMkisofsParameters() ) {
+      !addMkisofsParameters( true ) ) {
     cleanup();
     emit sizeCalculated( ERROR, 0 );
     return;
   }
 
-  *m_process << "-print-size" << "-quiet";
   // add empty dummy dir since one path-spec is needed
   *m_process << dummyDir();
 
@@ -397,6 +396,9 @@ void K3bIsoImager::start()
     return;
   }
 
+  // add empty dummy dir since one path-spec is needed
+  *m_process << dummyDir();
+
   connect( m_process, SIGNAL(processExited(KProcess*)),
 	   this, SLOT(slotProcessExited(KProcess*)) );
 
@@ -470,7 +472,7 @@ void K3bIsoImager::setMultiSessionInfo( const QString& info, K3bDevice* dev )
 }
 
 
-bool K3bIsoImager::addMkisofsParameters()
+bool K3bIsoImager::addMkisofsParameters( bool printSize )
 {
   // add multisession info
   if( !m_multiSessionInfo.isEmpty() ) {
@@ -484,6 +486,9 @@ bool K3bIsoImager::addMkisofsParameters()
   *m_process << "-gui";
   *m_process << "-graft-points";
 
+  if( printSize )
+    *m_process << "-print-size" << "-quiet";
+
   if( !m_doc->isoOptions().volumeID().isEmpty() ) {
     QString s = m_doc->isoOptions().volumeID();
     s.truncate(32);  // ensure max length
@@ -605,7 +610,7 @@ bool K3bIsoImager::addMkisofsParameters()
 	*m_process << "-no-emul-boot";
 	if( bootItem->loadSegment() > 0 )
 	  *m_process << "-boot-load-seg" << QString::number(bootItem->loadSegment());
-	if( bootItem->loadSegment() > 0 )
+	if( bootItem->loadSize() > 0 )
 	  *m_process << "-boot-load-size" << QString::number(bootItem->loadSize());
       }
 
